diff --git a/app/layout/aside_configure.phtml b/app/layout/aside_configure.phtml
index 1267f747c..e74630b5a 100644
--- a/app/layout/aside_configure.phtml
+++ b/app/layout/aside_configure.phtml
@@ -9,8 +9,8 @@
= _t('gen.menu.archiving') ?>
-
- = _t('gen.menu.sharing') ?>
+
+ = _t('gen.menu.sharing') ?>
= _t('gen.menu.shortcuts') ?>
diff --git a/app/layout/header.phtml b/app/layout/header.phtml
index 3f7bd80e3..7603cf2e5 100644
--- a/app/layout/header.phtml
+++ b/app/layout/header.phtml
@@ -61,7 +61,7 @@ if (FreshRSS_Auth::accessNeedsAction()) {
= _t('gen.menu.display') ?>
= _t('gen.menu.reading') ?>
= _t('gen.menu.archiving') ?>
- = _t('gen.menu.sharing') ?>
+ = _t('gen.menu.sharing') ?>
= _t('gen.menu.shortcuts') ?>
= _t('gen.menu.queries') ?>
= _t('gen.menu.user_profile') ?>
diff --git a/app/views/configure/sharing.phtml b/app/views/configure/integration.phtml
similarity index 100%
rename from app/views/configure/sharing.phtml
rename to app/views/configure/integration.phtml
diff --git a/docs/en/users/07_Frequently_Asked_Questions.md b/docs/en/users/07_Frequently_Asked_Questions.md
index fd3db4bea..e63c4c2c7 100644
--- a/docs/en/users/07_Frequently_Asked_Questions.md
+++ b/docs/en/users/07_Frequently_Asked_Questions.md
@@ -52,3 +52,14 @@ Some Linux distribution like Fedora or RedHat Enterprise Linux have SELinux syst
semanage fcontext -a -t httpd_sys_rw_content_t '/usr/share/FreshRSS/data(/.*)?'
restorecon -Rv /usr/share/FreshRSS/data
```
+
+## Why do I have a blank page while trying to configure the sharing options?
+
+The `sharing` word in the URL is a trigger word for some an-blocker rules. Starting at version 1.16, `sharing` has been replaced by `integration` in the faulty URL while keeping the exact same wording through out the application.
+
+If you are using a version prior to 1.16, you can disable your ad-blocker for FreshRSS or you can add a rule to allow the `sharing` page to be accessed.
+
+Examples with _uBlock_:
+
+- Whitelist your FreshRSS instance by adding it in _uBlock > Open the dashboard > Whitelist_.
+- Authorize your FreshRSS instance to call `sharing` configuration page by adding the rule `*sharing,domain=~yourdomain.com` in _uBlock > Open the dashboard > My filters_
diff --git a/app/Controllers/configureController.php b/app/Controllers/configureController.php
index b38d3289a..dcb438587 100755
--- a/app/Controllers/configureController.php
+++ b/app/Controllers/configureController.php
@@ -134,13 +134,16 @@ class FreshRSS_configure_Controller extends Minz_ActionController {
}
/**
* This action handles the sharing configuration page.
*
* It displays the sharing configuration page.
* If this action is reached through a POST request, it stores all
* configuration values then sends a notification to the user.
+ *
+ * Before v1.16, we used sharing instead of integration. This has
+ * some unwanted behavior when the end-user was using an ad-blocker.
*/
- public function sharingAction() {
+ public function integrationAction() {
if (Minz_Request::isPost()) {
$params = Minz_Request::fetchPOST();
FreshRSS_Context::$user_conf->sharing = $params['share'];
@@ -148,7 +151,7 @@ class FreshRSS_configure_Controller extends Minz_ActionController {
invalidateHttpCache();
Minz_Request::good(_t('feedback.conf.updated'),
- array('c' => 'configure', 'a' => 'sharing'));
+ array('c' => 'configure', 'a' => 'integration'));
}
Minz_View::prependTitle(_t('conf.sharing.title') . ' ยท ');
@@ -134,13 +134,16 @@ class FreshRSS_configure_Controller extends Minz_ActionController {
}
/**
- * This action handles the sharing configuration page.
+ * This action handles the integration configuration page.
*
@@ -134,13 +134,16 @@ class FreshRSS_configure_Controller extends Minz_ActionController {
*
- * It displays the sharing configuration page.
+ * It displays the integration configuration page.
* If this action is reached through a POST request, it stores all
* configuration values then sends a notification to the user.